@@ -9,9 +9,10 @@
 #' @method plot light_performance
 #' @param x An object of class \code{light_performance}.
 #' @param swap_dim Should representation of dimensions (either two "by" variables or one "by" variable and multiflashlight) of x aesthetic and dodge fill aesthetic be swapped? Default is FALSE.
+#' @param geom Geometry of plot (either "bar" or "point")
 #' @param facet_scales Scales argument passed to \code{facet_wrap}.
 #' @param rotate_x Should x axis labels be rotated by 45 degrees? Default is FALSE.
-#' @param ... Further arguments passed to \code{geom_bar}.
+#' @param ... Further arguments passed to \code{geom_bar} or \code{geom_point}.
 #' @return An object of class \code{ggplot2}.
 #' @export
 #' @examples
@@ -25,7 +26,9 @@
 #' plot(light_performance(mods, by = "Species"), swap_dim = TRUE)
 #' @seealso \code{\link{light_performance}}.
 plot.light_performance <- function(x, swap_dim = FALSE,
+                                   geom = c("bar", "point"),
                                    facet_scales = "free_y", rotate_x = FALSE, ...) {
+  geom <- match.arg(geom)
   data <- x$data
   nby <- length(x$by)
   multi <- is.light_performance_multi(x)
@@ -37,16 +40,24 @@ plot.light_performance <- function(x, swap_dim = FALSE,
 
   # Differentiate some plot cases
    if (ndim <= 1L) {
-    p <- ggplot(data, aes_string(y = x$value_name, x = if (nby) x$by[1] else x$label_name)) +
-      geom_bar(stat = "identity", ...)
+    p <- ggplot(data, aes_string(y = x$value_name, x = if (nby) x$by[1] else x$label_name))
+    if (geom == "bar") {
+      p <- p + geom_bar(stat = "identity", ...)
+    } else if (geom == "point") {
+      p <- p + geom_point(...)
+    }
   } else {
     second_dim <- if (multi) x$label_name else x$by[2]
     x_var <- if (!swap_dim) x$by[1] else second_dim
     dodge_var <- if (!swap_dim) second_dim else x$by[1]
 
-    p <- ggplot(data, aes_string(y = x$value_name, x = x_var)) +
-      geom_bar(aes_string(fill = dodge_var),
-               stat = "identity", position = "dodge", ...)
+    p <- ggplot(data, aes_string(y = x$value_name, x = x_var))
+    if (geom == "bar") {
+      p <- p + geom_bar(aes_string(fill = dodge_var),
+                        stat = "identity", position = "dodge", ...)
+    } else if (geom == "point") {
+      p <- p + geom_point(aes_string(group = dodge_var, color = dodge_var), ...)
+    }
   }
 
   # Multiple metrics always go into a facet due to different y scales
